/*
 * tridiag.cc
 * 
 * Thomas tridiagonal matrix algorithm (TDMA) to solve tridiagonal matrix 
 * equations. 
 * 
 * Copyright (c) 2004 by Wolfgang Wieser (wwieser@gmx.de) 
 * 
 * This file may be distributed and/or modified under the terms of the 
 * GNU General Public License version 2 as published by the Free Software 
 * Foundation. 
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

#include "elscore.h"
#include <math.h>


template<typename T>static inline
	void _SolveTridiag_M1_TDMA(int n,T *d,T *y,T *x)
{
	if(n>=1)
	{
		// Forward elimination: 
		double tmp=1.0/d[0];
		d[0]=tmp;
		y[0]*=tmp;
		for(int i=1; ; i++)
		{
			tmp=1.0/(d[i]-d[i-1]);
			y[i]=(y[i-1]+y[i])*tmp;
			if(i>=n)  break;
			d[i]=tmp;
		}
		// Backward substitution: 
		x[n]=y[n];
		for(int i=n-1; i>=0; i--)
			x[i]=d[i]*x[i+1]+y[i];
	}
	else if(!n)
		x[n]=y[n]/d[n];
}

void SolveTridiag_M1_TDMA(int n,double *d,double *y,double *x)
	{  _SolveTridiag_M1_TDMA(n,d,y,x);  }
