/*
 * mainwindow.h
 * 
 * ELStat's main window. 
 * 
 * Copyright (c) 2004 by Wolfgang Wieser (wwieser@gmx.de) 
 * 
 * This file may be distributed and/or modified under the terms of the 
 * GNU General Public License version 2 as published by the Free Software 
 * Foundation. 
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

#ifndef _ELSTAT_QTXGUI_MAINWINDOW_H_
#define _ELSTAT_QTXGUI_MAINWINDOW_H_ 1

#include "areasetup.h"
#include "areawindow.h"

#include <Qt/qwidget.h>


class QPushButton;
class QComboBox;
class QCcheckBox;

class StatusWindow;
struct DrawParams;

class MainWindow : public QWidget
{
	Q_OBJECT
	private:
		AreaWindow areawin;
		AreaSetupDialog asetup;
		ColorGradientDisplay *colgrad;
		
		QPushButton *area_button,*reset_button,*zero_button;
		QPushButton *start_button;  int start_button_text; // 0,1 = start/stop
		QComboBox *solver_mode;
		QSpinBox *limit_iterations;
		QSpinBox *limit_timeslice;
		QSpinBox *relax_omega;
		QCheckBox *periodic_bc;
		QSpinBox *eps_mant,*eps_exp;
		QComboBox *shuffle_mode;
		
		QSpinBox *ncolors_sel;
		
		QComboBox *shape_select;
		QComboBox *type_select;
		QSpinBox *potential_val;
		
		//StatusWindow *swin;
		
		void _UpdateValues();
		
		void _HandleKeyEvent(QKeyEvent *ev,int stat);
		
		void timerEvent(QTimerEvent *);
		void keyPressEvent(QKeyEvent *);
		void keyReleaseEvent(QKeyEvent *);
	private slots:
		void fillin_draw_params(DrawParams *);
		void fillin_solver_params(SolverParams *);
		void key_press_slot(QKeyEvent *);
		void key_release_slot(QKeyEvent *);
		void pde_converged(int);
		void solver_change(int);
		void reset_clicked();
		void zero_clicked();
		void start_clicked();
		void info_clicked();
		void quit_clicked();
		void runstate_change(int);
	public:
		MainWindow(QWidget *_parent=NULL,const char *name=NULL,WFlags f=0);
		~MainWindow();
};

#endif  /* _ELSTAT_QTXGUI_MAINWINDOW_H_ */
